@@ -1,25 +1,3 @@
-test_that("read_zip_url can download and read a zip file", {
-  skip_on_cran()
-
-  # read Bill of Rights (small file)
-  z <- read_zip_url("http://gutenberg.pglaf.org/0/2/2.zip")
-
-  expect_true(
-    any(
-      z == "Congress shall make no law respecting an establishment of religion,"
-    )
-  )
-})
-
-
-test_that("read_zip_url returns NULL on non-existent file", {
-  skip_on_cran()
-  z2 <- read_zip_url("http://gutenberg.pglaf.org/0/2/THISISNOTAFILE.zip")
-
-  expect_null(z2)
-})
-
-
 test_that("keep_while works", {
   x <- c("a", "b", "c", "d")
   expect_equal(keep_while(x, rep(TRUE, 4)), x)
@@ -34,7 +12,6 @@ test_that("discard_start_while works", {
   expect_equal(discard_start_while(x, c(FALSE, FALSE, FALSE, FALSE)), x)
 })
 
-
 test_that("discard_end_while works", {
   x <- c("a", "b", "c", "d")
   expect_equal(discard_end_while(x, rep(TRUE, 4)), x)
@@ -42,3 +19,38 @@ test_that("discard_end_while works", {
   expect_equal(discard_end_while(x, c(FALSE, FALSE, TRUE, TRUE)), x[1:2])
   expect_equal(discard_end_while(x, c(FALSE, FALSE, FALSE, FALSE)), x)
 })
+
+test_that("maybe_message might message", {
+  expect_message(
+    maybe_message(TRUE, "xyz"),
+    "xyz"
+  )
+  expect_no_message(
+    maybe_message(FALSE, "xyz")
+  )
+})
+
+test_that("read_url can download and read a zip file", {
+  local_dl_and_read()
+  # read Bill of Rights (small file)
+  z <- read_url("http://gutenberg.pglaf.org/0/2/2.zip")
+  expect_true(any(z == "Ratified December 15, 1791"))
+})
+
+test_that("read_url silently returns NULL on non-existent zip file", {
+  local_dl_and_read()
+  z <- read_url("http://gutenberg.pglaf.org/0/2/THISISNOTAFILE.zip")
+  expect_no_warning(expect_null(z))
+})
+
+test_that("read_url can download and read a txt file", {
+  local_dl_and_read()
+  z <- read_url("https://www.gutenberg.org/cache/epub/68283/pg68283.txt")
+  expect_true(any(z == "The CALL of CTHULHU"))
+})
+
+test_that("read_url returns NULL on non-existent txt file", {
+  local_dl_and_read()
+  z <- read_url("http://gutenberg.pglaf.org/0/2/THISISNOTAFILE.txt")
+  expect_no_warning(expect_null(z))
+})
